@@ -4,6 +4,9 @@ from tagging.models import Tag, TaggedItem
 from rblog.models import Post
 
 from django.conf import settings as conf
+from django.contrib.sites.models import Site
+from django.utils.translation import ugettext_lazy as _
+from django.template.loader import render_to_string
 
 class AllFeed(Feed):
 
@@ -17,6 +20,8 @@ class AllFeed(Feed):
     title = conf.SITE_TITLE
     link = "/"
     description = conf.SITE_DESCRIPTION
+    current_site = Site.objects.get(id=conf.SITE_ID)
+    blogurl = "http://"+current_site.domain
 
     def items(self):
         return Post.objects.all().filter(status=1).order_by('-creation_date')[:5]
@@ -28,7 +33,14 @@ class AllFeed(Feed):
         return item.get_absolute_url()
 
     def item_description(self, item):
-        return item.text
+
+        rendered = render_to_string('rblog/footerfeed.html',
+                                    {'link': self.blogurl+item.get_absolute_url(),
+                                     'title': item.title,
+                                     'linkblog':self.blogurl,
+                                     'blog':conf.SITE_TITLE})
+
+        return item.text + rendered
 
 class TagFeed(Feed):
 
@@ -42,7 +54,7 @@ class TagFeed(Feed):
 
     def get_object(self, request, tag):
         return Tag.objects.get(name=tag)
-        
+
     def items(self, obj):
         myposts = TaggedItem.objects.get_by_model(Post, obj)
         myposts = myposts.all().filter(status=1).order_by('-creation_date')[:5]
