@@ -18,14 +18,31 @@ class Link(object):
         self.before_text = node[3].text
         self.after_text = node[4].text
 
-def tla_list(request):
+@register.inclusion_tag('elements/tla_list.html', takes_context = True)
+def tla_list(context):
     """
     """
+    request = context['request']
     url = 'http://www.text-link-ads.com/xml.php?inventory_key=' +  conf.KEY_TLA + '&referer=' + request.META.get('REQUEST_URI', request.META.get('PATH_INFO', '/'))
     agent = '&user_agent=' + request.META['HTTP_USER_AGENT']
     links = ElementTree.parse(ElementTree(),urlopen(url+agent))
+
     return {
         'links': [ Link(link) for link in links ]
     }
 
-register.inclusion_tag('elements/tla_list.html')(tla_list)
+
+"""
+Template:
+{% load cache %}
+
+{% cache 21600 tla %}
+<ul id="tla">
+{% if links %}
+    {% for link in links %}
+    <li>{{ link.before_text }} <a href="{{ link.url }}">{{ link.text }}</a> {{ link.after_text }}</li>
+    {% endfor %}
+{% endif %}
+</ul>
+{% endcache %}
+"""
