@@ -37,7 +37,9 @@ class BlogIndexView(MetaSidebar, ListView):
         MetaSidebar.__init__(self)
 
     def get_queryset(self):
-        return mymodels.Post.objects.all().filter(status=1).order_by('-creation_date')
+        print datetime.datetime.now()
+        return mymodels.Post.objects.all().filter(status=1,
+            creation_date__lte=datetime.datetime.now()).order_by('-creation_date')
 
     def get_context_data(self, **kwargs):
         context = super(BlogIndexView, self).get_context_data(**kwargs)
@@ -102,7 +104,8 @@ class PostsWithTag(MetaSidebar, ListView):
     def get_queryset(self):
         query_tag = Tag.objects.get(name=self.kwargs['tag'])
         myposts = TaggedItem.objects.get_by_model(mymodels.Post, query_tag)
-        return myposts.all().filter(status=1).order_by('-creation_date')
+        return myposts.all().filter(status=1,
+            creation_date__lte=datetime.datetime.now()).order_by('-creation_date')
 
     def get_context_data(self, **kwargs):
         context = super(PostsWithTag, self).get_context_data(**kwargs)
@@ -126,8 +129,9 @@ class PostsByDate(MetaSidebar, ListView):
     def get_queryset(self):
         archive = str(self.kwargs['month']) + '.' + str(self.kwargs['year'])
         return mymodels.Post.objects.all().filter(status=1,
-                creation_date__month=self.kwargs['month'],
-                creation_date__year=self.kwargs['year']).order_by('-creation_date')
+            creation_date__lte=datetime.datetime.now(),
+            creation_date__month=self.kwargs['month'],
+            creation_date__year=self.kwargs['year']).order_by('-creation_date')
 
     def get_context_data(self, **kwargs):
         context = super(PostsByDate, self).get_context_data(**kwargs)
@@ -150,7 +154,8 @@ class AJAXArchive(ListView):
     def get_context_data(self, **kwargs):
         context = super(AJAXArchive, self).get_context_data(**kwargs)
 
-        first_post = mymodels.Post.objects.all().filter(status=1).order_by('creation_date')[0]
+        first_post = mymodels.Post.objects.all().filter(status=1,
+            creation_date__lte=datetime.datetime.now()).order_by('creation_date')[0]
         year_ini = int(first_post.creation_date.strftime("%Y"))
         year_hoy = datetime.datetime.now().year
         mes_hoy = datetime.datetime.now().month
